/* (c) 1996-2001, Jan D. Wolter and Steven R. Weiss, All Rights Reserved. */

/* Unix Passwd File Identification Database Interface
 *
 * This module supports using the unix password file as your identification
 * database.  It's always your authentication database too.
 */

#include "common.h"
#include "authident.h"

#include <ctype.h>
#include <errno.h>
#include <sys/stat.h>
#include <pwd.h>
#ifdef HAVE_SYS_FILE_H
#include <sys/file.h>
#endif

#include "set_uid.h"
#include "str.h"
#include "lock.h"
#include "entropy.h"

#ifdef DMALLOC
#include "dmalloc.h"
#endif

char *showopt_ident_module= "ident_passwd";

/* PWCPY - This copies a password file entry from the Unix passwd structure
 * to a Backtalk passwd structure.
 */

void pwcpy(struct btpasswd *btpw, struct passwd *pw)
{
    /* Eliminate office/phone number */
    *firstin(pw->pw_gecos,",")= '\0';

    /* Turn one character passwords into empty strings */
    if (pw->pw_passwd[1] == '\0') pw->pw_passwd[0]= '\0';

    /* Copy */
    btpw->name= pw->pw_name;
    btpw->passwd= pw->pw_passwd;
    btpw->uid= pw->pw_uid;
    btpw->gid= pw->pw_gid;
    btpw->gecos= pw->pw_gecos;
    btpw->dir= pw->pw_dir;
    btpw->email= NULL;
    btpw->valcode= NULL;
    btpw->priv= -1;
    btpw->epriv= -1;
}


#ifdef HAVEIDENT_GETPWNAM
struct btpasswd *ident_getpwnam(char *login)
{
    struct passwd *pw;
    static struct btpasswd btpw;
    pw= getpwnam(login);
    if (pw == NULL) return NULL;
    pwcpy(&btpw,pw);
    return &btpw;
}
#endif


#ifdef HAVEIDENT_GETPWUID
struct passwd *ident_getpwuid(uid_t uid)
{
    struct passwd *pw;
    pw= getpwuid(uid);
    if (pw == NULL) return NULL;
    pwcpy(&btpw,pw);
    return &btpw;
}
#endif


#ifdef HAVEIDENT_WALKPW
struct passwd *ident_walkpw(int flag)
{
    struct passwd *pw;

    /* If flag is 0, goto begining of file */
    if (!flag) setpwent();

    /* Get next */
    pw= getpwent();
    if (pw == NULL) return NULL;
    pwcpy(&btpw,pw);
    return &btpw;
}
#endif
