/* (c) 2004, Jan D. Wolter, All Rights Reserved. */

/* Test driver for http_client.c */

#include "common.h"
#include "http_client.h"

void dumprq(struct rq *req)
{
    if (req == NULL)
    {
	printf("No Request\n");
	return;
    }

    switch (req->method)
    {
    case RM_GET: printf("METHOD: GET\n"); break;
    case RM_POST: printf("METHOD: POST\n"); break;
    case RM_HEAD: printf("METHOD: HEAD\n"); break;
    case RM_XML_RPC: printf("METHOD: XML-RPC\n"); break;
    default: printf("METHOD: %s\n", req->method); break;
    }

    printf("HOST: %s\n",req->host);
    printf("PORT: %d\n",req->port);
    printf("PATH: %s\n",req->path);
    if (req->query) printf("QUERY: %s\n",req->query);
    if (req->user) printf("USER: %s\n",req->user);
    if (req->password) printf("PASSWORD: %s\n",req->password);
    printf("REDIRECT: %s\n",req->redirect ? "true" : "false");
}


void dumprp(struct rp *resp)
{
    if (resp == NULL)
    {
	printf("No Response\n");
	return;
    }

    printf("STATUS: %d\n",resp->status);
    if (resp->reason) printf("REASON: %s\n",resp->reason);
    if (resp->redirect) printf("REDIRECT: %s\n",resp->redirect);
    if (resp->authrealm) printf("AUTH REALM: %s\n",resp->authrealm);
    if (resp->type) printf("CONTENT TYPE: %s\n",resp->type);
    if (resp->content) printf("CONTENT:\n%s\n",resp->content);
}


int main(int argc, char **argv)
{
    char *uri= NULL;
    int method= RM_NONE;
    struct px *proxy= NULL;
    struct rp *resp= NULL;
    struct rq *req= NULL;
    int redir= TRUE;
    int i,j;

    for (i= 1; i < argc; i++)
    {
	if (argv[i][0] == '-')
	    for (j= 1; argv[i][j] != '\0'; j++)
		switch (argv[i][j])
		{
		    case 'r': redir= FALSE; break;
		    default: goto usage;
		}
	else if (method == RM_NONE)
	{
	    if ((method= method_code(argv[i])) == RM_NONE)
		goto usage;
	}
	else if (uri == NULL)
	    uri= argv[i];
	else if (proxy == NULL)
	{
	    if ((proxy= parse_proxy(argv[i])) == NULL)
		goto usage;
	}
	else
	    goto usage;
    }
    if (uri == NULL) goto usage;

    req= uri_request(uri, method);
    if (req != NULL) req->redirect= redir;
    printf("Request\n=========================\n");
    dumprq(req);

    resp= execute_request(req, proxy);
    printf("\nResponse\n=========================\n");
    dumprp(resp);

    free_response(resp);
    free_proxy(proxy);

    exit(0);

usage:
    fprintf(stderr,
	"usage: %s [-r] GET|POST|HEAD <uri> [<proxy>[:<port>]]\n",
	argv[0]);
    exit(1);
}
